==> dstack-0.19.4rc3.tar.gz: dstack-0.19.4rc3/docs/examples.md <==
---
#template: examples.html
hide:
   - navigation
#   - toc
   - footer
---

<style>
.md-main .md-main__inner.md-grid {
    flex-direction: row-reverse;
}
</style>

## Deployment
<div class="tx-landing__highlights_grid">
    <a href="/examples/deployment/vllm" 
       class="feature-cell">
       <h3>
           vLLM
       </h3>
       <p>
            Deploy Llama 3.1 with vLLM
        </p>
    </a>
    <a href="/examples/deployment/tgi" 
       class="feature-cell">
       <h3>
           TGI
       </h3>
       <p>
            Deploy Llama 3.1 with TGI
        </p>
    </a>
    <a href="/examples/deployment/nim" 
       class="feature-cell">
       <h3>
           NIM
       </h3>
       <p>
            Deploy DeepSeek R1 Distill Llama 8B with NIM
        </p>
    </a>
    <a href="/examples/deployment/sglang" 
       class="feature-cell">
       <h3>
           SGLang
       </h3>
       <p>
           Deploy DeepSeek-R1-Distill-Llama 8B & 70B with SGLang
      </p>
    </a>
</div>

## Fine-tuning

<div class="tx-landing__highlights_grid">
    <a href="/examples/fine-tuning/axolotl"
       class="feature-cell">
        <h3>
            Axolotl
        </h3>

        <p>
            Fine-tune Llama 3 on a custom dataset using Axolotl.
        </p>
    </a>

    <a href="/examples/fine-tuning/trl"
       class="feature-cell">
        <h3>
            TRL
        </h3>

        <p>
            Fine-tune Llama 3.1 8B on a custom dataset using TRL.
        </p>
    </a>
</div>

## Accelerators

<div class="tx-landing__highlights_grid">
    <a href="/examples/accelerators/amd"
       class="feature-cell sky">
        <h3>
            AMD
        </h3>

        <p>
            Deploy and fine-tune LLMs on AMD
        </p>
    </a>

    <a href="/examples/accelerators/intel"
       class="feature-cell sky">
        <h3>
            Intel Gaudi
        </h3>

        <p>
            Deploy and fine-tune LLMs on Intel Gaudi
        </p>
    </a>


    <a href="/examples/accelerators/tpu"
       class="feature-cell sky">
        <h3>
            TPU
        </h3>

        <p>
            Deploy and fine-tune LLMs on TPU
        </p>
    </a>
</div>

## LLMs

<div class="tx-landing__highlights_grid">
    <a href="/examples/llms/deepseek"
       class="feature-cell sky">
        <h3>
            Deepseek
        </h3>

        <p>
            Deploy and train Deepseek models
        </p>
    </a>
    <a href="/examples/llms/llama"
       class="feature-cell sky">
        <h3>
            Llama
        </h3>

        <p>
            Deploy Llama 4 models
        </p>
    </a>
</div>

## Misc

<div class="tx-landing__highlights_grid">
    <a href="/examples/misc/docker-compose"
       class="feature-cell sky">
        <h3>
            Docker Compose
        </h3>

        <p>
            Use Docker and Docker Compose inside runs
        </p>
    </a>
    <a href="/examples/misc/nccl-tests"
       class="feature-cell sky">
        <h3>
            NCCL tests
        </h3>

        <p>
            Run multi-node NCCL tests with MPI
        </p>
    </a>
    <a href="/examples/misc/a3mega-clusters"
       class="feature-cell sky">
        <h3>
            A3 Mega
        </h3>

        <p>
            Set up GCP A3 Mega clusters with optimized networking
        </p>
    </a>
</div>

==> dstack-0.19.6.tar.gz: dstack-0.19.6/docs/examples.md <==
---
#template: examples.html
hide:
   - navigation
#   - toc
   - footer
---

<style>
.md-main .md-main__inner.md-grid {
    flex-direction: row-reverse;
}
</style>

## Deployment
<div class="tx-landing__highlights_grid">
    <a href="/examples/deployment/sglang" 
       class="feature-cell">
       <h3>
           SGLang
       </h3>
       <p>
           Deploy DeepSeek distilled models with SGLang
      </p>
    </a>
    <a href="/examples/deployment/vllm" 
       class="feature-cell">
       <h3>
           vLLM
       </h3>
       <p>
            Deploy Llama 3.1 with vLLM
        </p>
    </a>
    <a href="/examples/deployment/tgi" 
       class="feature-cell">
       <h3>
           TGI
       </h3>
       <p>
            Deploy Llama 4 with TGI
        </p>
    </a>
    <a href="/examples/deployment/nim" 
       class="feature-cell">
       <h3>
           NIM
       </h3>
       <p>
            Deploy a DeepSeek distilled model with NIM
        </p>
    </a>
    <a href="/examples/deployment/trtllm"
       class="feature-cell">
       <h3>
           TensorRT-LLM
       </h3>
       <p>
            Deploy DeepSeek R1 and its distilled version with TensorRT-LLM
        </p>
    </a>
</div>

## Fine-tuning

<div class="tx-landing__highlights_grid">
    <a href="/examples/fine-tuning/axolotl"
       class="feature-cell">
        <h3>
            Axolotl
        </h3>

        <p>
            Fine-tune Llama 4 on a custom dataset using Axolotl.
        </p>
    </a>

    <a href="/examples/fine-tuning/trl"
       class="feature-cell">
        <h3>
            TRL
        </h3>

        <p>
            Fine-tune Llama 3.1 8B on a custom dataset using TRL.
        </p>
    </a>
</div>

## Accelerators

<div class="tx-landing__highlights_grid">
    <a href="/examples/accelerators/amd"
       class="feature-cell sky">
        <h3>
            AMD
        </h3>

        <p>
            Deploy and fine-tune LLMs on AMD
        </p>
    </a>

    <a href="/examples/accelerators/intel"
       class="feature-cell sky">
        <h3>
            Intel Gaudi
        </h3>

        <p>
            Deploy and fine-tune LLMs on Intel Gaudi
        </p>
    </a>


    <a href="/examples/accelerators/tpu"
       class="feature-cell sky">
        <h3>
            TPU
        </h3>

        <p>
            Deploy and fine-tune LLMs on TPU
        </p>
    </a>
</div>

## LLMs

<div class="tx-landing__highlights_grid">
    <a href="/examples/llms/deepseek"
       class="feature-cell sky">
        <h3>
            Deepseek
        </h3>

        <p>
            Deploy and train Deepseek models
        </p>
    </a>
    <a href="/examples/llms/llama"
       class="feature-cell sky">
        <h3>
            Llama
        </h3>

        <p>
            Deploy Llama 4 models
        </p>
    </a>
</div>

## Misc

<div class="tx-landing__highlights_grid">
    <a href="/examples/misc/docker-compose"
       class="feature-cell sky">
        <h3>
            Docker Compose
        </h3>

        <p>
            Use Docker and Docker Compose inside runs
        </p>
    </a>
    <a href="/examples/misc/nccl-tests"
       class="feature-cell sky">
        <h3>
            NCCL tests
        </h3>

        <p>
            Run multi-node NCCL tests with MPI
        </p>
    </a>
    <a href="/examples/misc/a3mega-clusters"
       class="feature-cell sky">
        <h3>
            A3 Mega
        </h3>

        <p>
            Set up GCP A3 Mega clusters with optimized networking
        </p>
    </a>
    <a href="/examples/misc/a3high-clusters"
       class="feature-cell sky">
        <h3>
            A3 High
        </h3>

        <p>
            Set up GCP A3 High clusters with optimized networking
        </p>
    </a>
</div>
